@@ -1,4 +1,4 @@
-# Copyright (C) 2004-2012 by Barry A. Warsaw
+# Copyright (C) 2004-2014 by Barry A. Warsaw
 #
 # This file is part of flufl.lock
 #
@@ -16,7 +16,7 @@
 
 """Package init."""
 
-from __future__ import absolute_import, unicode_literals
+from __future__ import absolute_import, print_function, unicode_literals
 
 __metaclass__ = type
 __all__ = [
@@ -29,7 +29,7 @@ __all__ = [
     ]
 
 
-__version__ = '2.2.1'
+__version__ = '2.3'
 
 
 # Public API.
